\name{permax}
\alias{permax}
\title{
2-sample permutation t-tests for high dimensional data
}
\description{
For high dimensional vectors of observations, computes t statistics for
each attribute, and assesses significance using the permutation
distribution of the maximum and minimum over all attributes.
}
\usage{
permax(data, ig1, nperm=0, logs=TRUE, ranks=FALSE, min.np=1, ig2, WHseed=NULL)
}
\arguments{
\item{data}{
Data matrix or data frame.  Each case is a column, and each row is an
attribute (the opposite of the standard configuration).
}
\item{ig1}{
The columns of data corresponding to group 1
}
\item{nperm}{
The number of random permutations to use in computing the p-values.
The default is to use the entire permutation distribution, which is
only feasible if the sample sizes are fairly small
}
\item{logs}{
If \code{logs=TRUE} (the default), then logs of the values in data are used in
the statistics.
}
\item{ranks}{
If ranks=T, then within row ranks are used in place of the values in
data in the t statistics.  This is equivalent to using the Wilcoxon
statistic.  Default is ranks=F
}
\item{min.np}{
data will be subset to only rows with at least min.np values larger
than min(data) in the columns in ig1 and ig2 
}
\item{ig2}{
The columns of data corresponding to group 2.  The default is to
include all columns not in ig1 in group 2.  When both ig1 and ig2 are
given, columns not in either are excluded from the tests.
}
\item{WHseed}{
Initial random number seed (a vector of 3 integers).  If missing, an
initial seed is generated from the runif() function.  Not needed if all
permutations are calculated.
}
}

\value{
Output is a data.frame of class 'permax', with columns
  stat: the standardized test statistics for each row
  pind: individual permutation p-values (2-sided)
  p2: 2-sided p-value using the distribution of the max overall rows
  p.lower: 1-sided p-value for lower levels in group 1
  p.upper: 1-sided p-value for higher levels in group 1
  nml: \# permutations where this row was the most significant for p.lower
  nmr: \# permutations where this row was the most sig for p.upper
  m1, m2: means of groups 1 and 2 (means of logs if logs=T)
  s1, s2: std deviations of groups 1 and 2 (of logs if logs=T)
  np1,np2: \# values > min(data) in groups 1 and 2
  mdiff: difference of means (if logs=T the difference of geometric means)
  mrat: ratio of means (if logs=T ratio of geometric means)


Also, if nperm>0, then output includes attributes 'seed.start' giving
the initial random number seed, and 'seed.end' giving the value of the
seed at the end.  These can be accessed with the attributes() and
attr() functions.
}

\details{
For DNA array data, this function is designed to identify the genes
which best discriminate between two tissue types.  2-sample t
statistics are computed for each gene using logs (default), raw values,
or ranks.  Upper and lower p-values (p.upper, p.lower) are computed by
comparing each statistic to the permutation distribution of the maximum
and minimum (largest negative) statistic over all genes.  The \code{pind}
component of the output gives the p-value for the permutation
distribution of each individual gene.


It is strongly recommended that different seeds be used for different
runs, and ideally the final seed from one run, attr(output,'seed.end'),
would be used as the initial seed in the next run.
}
\seealso{
summary.permax, plot.permax, permcor, permsep.
}
\examples{
#generate make believe data
   set.seed(1292)
   ngenes <- 1000
   m1 <- rnorm(ngenes,4,1)
   m2 <- rnorm(ngenes,4,1)
    exp1 <- cbind(matrix(exp(rnorm(ngenes*5,m1,1)),nrow=ngenes),
               matrix(exp(rnorm(ngenes*10,m2,1)),nrow=ngenes))
   exp1[exp1<20] <- 20
   sub <- exp1>20 & exp1<150
   exp1[sub] <- ifelse(runif(length(sub[sub]))<.5,20,exp1[sub])
   dimnames(exp1) <- list(paste('x',format(1:ngenes,justify='l'),sep=''),
                     paste('sample',format(1:ncol(exp1),justify='l'),sep=''))
   dimnames(exp1) <- list(paste('x',1:ngenes,sep=''),
                     paste('sample',1:ncol(exp1),sep=''))
   exp1 <- round(exp1)

   uu <- permax(exp1,1:5)
  summary(uu,nl=5,nr=5) # 5 most extreme in each direction
}
\keyword{htest}

% Converted by Sd2Rd version 1.19.

\eof
\name{permcor}
\alias{permcor}
\title{
permutation tests for correlations in high dimensional data
}
\description{
For high dimensional vectors of observations, computes the correlation
coefficient for each attribute with a specified vector of values, and
assesses significance using the permutation distribution of the maximum
and minimum over all attributes.
}
\usage{
permcor(data, phen, nperm=1000, logs=TRUE, ranks=FALSE, min.np=1, WHseed=NULL)
}
\arguments{
\item{data}{
Data matrix or data frame.  Each case is a column, and each row is an
attribute (the opposite of the standard configuration).
}
\item{phen}{
A vector of values (the ideal phenotype pattern).  The correlations of
each row of data with phen will be computed.
}
\item{nperm}{
The number of random permutations to use in computing the p-values.
The default is 1000.  If nperm is < 0, the entire permutation
distribution will be used, which is only feasible if the sample size is
fairly small 
}
\item{logs}{
If logs=TRUE (the default), then logs of the values in data are used in
computing correlations (the actual values of phen are used, though).
}
\item{ranks}{
If ranks=T, then within row ranks are used in place of the values in
data in the correlations.  The actual values of phen are still used.  
Default is ranks=FALSE.
}
\item{min.np}{
data will be subset to only rows with at least min.np values larger
than min(data).
}
\item{WHseed}{
Initial random number seed (a vector of 3 integers).  If missing, an
initial seed is generated from the runif() function.  Not needed if all
permutations are calculated.
}
}
\value{
Output is a data.frame of class c('permcor','permax'), with columns
  stat: the Pearson correlation coeffcients for each row of data
  pind: individual permutation p-values (2-sided)
  p2: 2-sided p-value using the distribution of the max overall rows
  p.lower: 1-sided p-value for lower levels in group 1
  p.upper: 1-sided p-value for higher levels in group 1
  nml: \# permutations where this row was the most significant for p.lower
  nmr: \# permutations where this row was the most sig for p.upper
  np: \# values > min(data) in each row


Also, if nperm>0, then output includes attributes 'seed.start' giving
the initial random number seed, and 'seed.end' giving the value of the
seed at the end.  These can be accessed with the attributes() and
attr() functions.
}

\details{
For DNA array data, this function is designed to identify the genes
with the largest positive and negative correlations with the phenotype
in phen.  Upper and lower p-values (p.upper, p.lower) are computed by
comparing each correlation to the permutation distribution of the maximum
and minimum (largest negative) correlations over all genes.  The \code{pind}
component of the output gives the p-value for the permutation
distribution of each individual gene.


If phen is a vector of 1's for the columns in group 1 and 0's for the
other columns, then the p-values from permcor() should be the same as
from permax() (to within simulation precision if random permutations
are used).  permax() is substantially more efficient in this setting.


The functions summary.permax() and plot.permax() can be used with the
output of permcor().


It is strongly recommended that different seeds be used for different
runs, and ideally the final seed from one run, attr(output,'seed.end'),
would be used as the initial seed in the next run.
}
\seealso{
permax, summary.permax, plot.permax.
}
\examples{
   set.seed(1292)
   ngenes <- 1000
   m1 <- rnorm(ngenes,4,1)
   m2 <- rnorm(ngenes,4,1)
    exp1 <- cbind(matrix(exp(rnorm(ngenes*5,m1,1)),nrow=ngenes),
               matrix(exp(rnorm(ngenes*10,m2,1)),nrow=ngenes))
   exp1[exp1<20] <- 20
   sub <- exp1>20 & exp1<150
   exp1[sub] <- ifelse(runif(length(sub[sub]))<.5,20,exp1[sub])
   dimnames(exp1) <- list(paste('x',format(1:ngenes,justify='l'),sep=''),
                     paste('sample',format(1:ncol(exp1),justify='l'),sep=''))
   dimnames(exp1) <- list(paste('x',1:ngenes,sep=''),
                     paste('sample',1:ncol(exp1),sep=''))
   exp1 <- round(exp1)

#see the permax help file for the definition of exp1
  u8 <- permcor(exp1,1:15)
 summary(u8,nr=4,nl=4)
 u10 <- permcor(exp1[,c(1:3,5:8)],c(1,1,1,0,0,0,0),nperm=0)


 summary(u10,nl=4,nr=4)

}
\keyword{htest}

% Converted by Sd2Rd version 1.19.

\eof
\name{permsep}
\alias{permsep}
\title{
Permutation analysis for complete separation
}
\description{
Given two groups of samples of high dimensional attribute vectors (eg
DNA array expression levels), determines the number of attributes which
completely separate the two groups (all values in one group strictly
larger than in the other), and a permutation p-value for this quantity.
}
\usage{
permsep(data, ig1, nperm=0, ig2, WHseed=NULL)
}
\arguments{
\item{data}{
Data matrix or data frame.  Each case is a column, and each row is an
attribute (the opposite of the standard configuration).
}
\item{ig1}{
The columns of data corresponding to group 1
}
\item{nperm}{
The number of random permutations to use in computing the p-values.
The default is to use the entire permutation distribution, which is
only feasible if the sample sizes are fairly small
}
\item{ig2}{
The columns of data corresponding to group 2.  The default is to
include all columns not in ig1 in group 2.  When both ig1 and ig2 are
given, columns not in either are excluded.
}
\item{WHseed}{
Initial random number seed (a vector of 3 integers).  If missing, an
initial seed is generated from the runif() function.  Not needed if all
permutations are calculated.


Prints a vector giving the \# genes with complete separation (all in one group 
larger than all in the other, the proportion of permutations with
this many or more genes with complete separation (p-value) ('permutation'
actually means a distinct rearrangement of columns into 2 groups), the 
average number of genes per permutation with complete separation, 
and the proportion of permutations with any genes with complete
separation.  


The value returned is a list with components \code{ics} = a vector indicating
(with 1) which rows of data have complete separation, and \code{dtcs} = a
vector containing the printed output.


Also, if \code{nperm}>0, then the output includes attributes \code{seed.start}
giving the initial random number seed, and \code{seed.end} giving the value
of the seed at the end.  These can be accessed with the
\code{\link{attributes}} 
and \code{\link{attr}} functions.


}}
\details{
For each gene there will be 0, 1 or 2 rearrangements with complete
separation, depending on the number of unique values and the sizes of
the two groups.  Adding these numbers over genes and dividing by the
number of rearrangements gives the average number per permutation.  The
value returned averages only over the rearrangements actually used,
though.


It is strongly recommended that different seeds be used for different
runs, and ideally the final seed from one run, attr(output,'seed.end'),
would be used as the initial seed in the next run.


}
\seealso{
permax
}
\examples{
   ngenes <- 1000
   m1 <- rnorm(ngenes,4,1)
   m2 <- rnorm(ngenes,4,1)
    exp1 <- cbind(matrix(exp(rnorm(ngenes*5,m1,1)),nrow=ngenes),
               matrix(exp(rnorm(ngenes*10,m2,1)),nrow=ngenes))
   exp1[exp1<20] <- 20
   sub <- exp1>20 & exp1<150
   exp1[sub] <- ifelse(runif(length(sub[sub]))<.5,20,exp1[sub])
   dimnames(exp1) <- list(paste('x',format(1:ngenes,justify='l'),sep=''),
                     paste('sample',format(1:ncol(exp1),justify='l'),sep=''))
   dimnames(exp1) <- list(paste('x',1:ngenes,sep=''),
                     paste('sample',1:ncol(exp1),sep=''))
   exp1 <- round(exp1)

 uuu <- permsep(exp1,1:5)

}
\keyword{htest}
% Converted by Sd2Rd version 1.19.

\eof
\name{plot.expr}
\alias{plot.expr}
\title{
Color image plot of gene expression levels
}
\description{
Represents values in the rows of a matrix as colored rectangles in an
image plot
}
\usage{
plot.expr(x, logs=TRUE, ig1=NULL, ig2=NULL, clmn.lab=dimnames(x)[[2]], 
    row.lab=dimnames(x)[[1]], clmn.off=NULL, row.off=NULL,\dots)
}
\arguments{
\item{x}{
matrix or \code{data.frame} containing the values to be plotted.
}
\item{logs}{
If \code{logs=TRUE}, then log values are used.
}
\item{ig1}{
The columns of \code{x} for cases in group 1 (see Details)
}
\item{ig2}{
The columns in group 2.  By default, all the columns not in group 1.
}
\item{clmn.lab}{
Labels for the columns in the array.
}
\item{row.lab}{
Labels for the rows in the array.
}
\item{clmn.off}{
Offset for printing the column labels (<0 to put labels
outside the plot).
}
\item{row.off}{
Offset for printing the row labels (<0 to put labels
outside the plot).
}
\item{...}{
Additional arguments to \code{image} and \code{text} (see \code{par})
none
}}
\section{Side Effects}{
An image plot is created on the current graphics device
}
\details{
Values within a row are centered and normalized to have variance 1.  If
\code{ig1} is not given, then the values are centered to have mean 0.
If \code{ig1} 
is given, the values are centered so the means of the columns in
\code{ig1} 
and \code{ig2} are equal in magnitude and opposite in direction.  The
plot is 
thus useful for comparing within rows, but differences in colors
between rows have no meaning.


A graphics device supporting image plots must be initialized prior to
calling this function.  Under Splus 3.4 for unix, the following command
(without the line breaks) initializes the X window motif plot window to
use 30 colors from blue (lowest levels) to yellow (highest levels) for
the image plots (in this scheme a value half way between the lowest and
highest values would be a medium intensity gray).


  motif("-xrm 'sgraphMotif.colorSchemes : background : black; lines :
  yellow cyan magenta green MediumBlue red; text : white yellow cyan
  magenta green MediumBlue red; images : blue 30 yellow'")


}
\seealso{
\code{plot.permax}
}
\examples{
   set.seed(1292)
   ngenes <- 1000
   m1 <- rnorm(ngenes,4,1)
   m2 <- rnorm(ngenes,4,1)
    exp1 <- cbind(matrix(exp(rnorm(ngenes*5,m1,1)),nrow=ngenes),
               matrix(exp(rnorm(ngenes*10,m2,1)),nrow=ngenes))
   exp1[exp1<20] <- 20
   sub <- exp1>20 & exp1<150
   exp1[sub] <- ifelse(runif(length(sub[sub]))<.5,20,exp1[sub])
   dimnames(exp1) <- list(paste('x',format(1:ngenes,justify='l'),sep=''),
                     paste('sample',format(1:ncol(exp1),justify='l'),sep=''))
   dimnames(exp1) <- list(paste('x',1:ngenes,sep=''),
                     paste('sample',1:ncol(exp1),sep=''))
   exp1 <- round(exp1)

  plot.expr(exp1[1:20,])
}
\keyword{hplot}

% Converted by Sd2Rd version 1.19.

\eof
\name{plot.permax}
\alias{plot.permax}
\title{
Image plot of the most significant genes (attributes) from a permax
analysis 
}
\description{
Given the output of \code{permax}, and the array of expression levels,
creates a color image plot of the expression levels of the most
significant genes 
}
\usage{
plot.permax(x, data, nl=25, nr=25, logs=TRUE, ig1=NULL, ig2=NULL, 
  clmn.lab=dimnames(data)[[2]], row.lab=dimnames(data)[[1]], 
  clmn.off=NULL, row.off=NULL, \dots)
}
\arguments{
\item{x}{
A permax object (output from \code{permax})
}
\item{data}{
Matrix or data frame of expression levels used as input to \code{permax}
}
\item{nl}{
The nl most significant genes in the lower tail will be plotted
}
\item{nr}{
The nr most significant genes in the upper tail will be plotted
}
\item{logs}{
If \code{logs=TRUE}, then log values are used.
}
\item{ig1}{
The columns of data for cases in group 1 (see Details)
}
\item{ig2}{
The columns in group 2.  By default, all the columns not in group 1.
}
\item{clmn.lab}{
Labels for the columns in the array.
}
\item{row.lab}{
Labels for the rows in the array.
}
\item{clmn.off}{
Offset for printing the column labels (<0 to put labels
outside the plot).
}
\item{row.off}{
Offset for printing the row labels (<0 to put labels
outside the plot).
}
\item{...}{
Additional arguments to \code{image} and \code{text} (see \code{par})
none
}}
\section{Side Effects}{
An image plot is created on the current graphics device
}
\details{
Values within a row of data are centered and normalized to have
variance 1.  If \code{ig1} is not given, then the values are centered to have
mean 0.  If \code{ig1} is given, the values are centered so the means of the
columns in \code{ig1} and ig2 are equal in magnitude and opposite in direction
(usually \code{ig1} and ig2 should match the values used in the \code{permax}
call).  The plot is thus useful for comparing within rows, but
differences in colors between rows have no meaning.


The plot will give the most significant lower tail genes in the top
portion (most significant at the top), and the most significant upper
tail genes in the bottom portion (most significant at the bottom). 


This function just selects out the appropriate rows of data, and calls
plot.expr().  row.names(data) or dimnames(data)[[1]] must correspond to
row.names(Z) for the selection to work properly.


A graphics device supporting image plots must be initialized prior to
calling this function.  Under Splus 3.4 for unix, the following command
(without the line breaks) initializes the X window motif plot window to
use 30 colors from blue (lowest levels) to yellow (highest levels) for
the image plots (in this scheme a value half way between the lowest and
highest values would be a medium intensity gray).


  motif("-xrm 'sgraphMotif.colorSchemes : background : black; lines :
  yellow cyan magenta green MediumBlue red; text : white yellow cyan
  magenta green MediumBlue red; images : blue 30 yellow'")
}
\seealso{
permax, plot.expr
}
\examples{
 set.seed(1292)
   ngenes <- 1000
   m1 <- rnorm(ngenes,4,1)
   m2 <- rnorm(ngenes,4,1)
    exp1 <- cbind(matrix(exp(rnorm(ngenes*5,m1,1)),nrow=ngenes),
               matrix(exp(rnorm(ngenes*10,m2,1)),nrow=ngenes))
   exp1[exp1<20] <- 20
   sub <- exp1>20 & exp1<150
   exp1[sub] <- ifelse(runif(length(sub[sub]))<.5,20,exp1[sub])
   dimnames(exp1) <- list(paste('x',format(1:ngenes,justify='l'),sep=''),
                     paste('sample',format(1:ncol(exp1),justify='l'),sep=''))
   dimnames(exp1) <- list(paste('x',1:ngenes,sep=''),
                     paste('sample',1:ncol(exp1),sep=''))
   exp1 <- round(exp1)

  uu <- permax(exp1,1:5)
  plot(uu,exp1,ig1=1:5,cex=.7)
}
\keyword{hplot}

% Converted by Sd2Rd version 1.19.

\eof
\name{rowperm}
\alias{rowperm}
\title{
Generates random permutations within rows of a matrix
}
\description{
Given a matrix x, returns a copy of x with a separate random
permutations applied within each row.
}
\usage{
rowperm(x)
}
\arguments{
\item{x}{
a numeric matrix
A numeric matrix with each row containing the elements from the
corresponding row of x permuted in a random order.
}}
\examples{
 x <- matrix(1:12,3)
 x
#     [,1] [,2] [,3] [,4] 
#[1,]    1    4    7   10
#[2,]    2    5    8   11
#[3,]    3    6    9   12
  rowperm(x)
#     [,1] [,2] [,3] [,4] 
#[1,]   10    7    1    4
#[2,]    8   11    2    5
#[3,]    6   12    9    3

}
\keyword{utilities}
% Converted by Sd2Rd version 1.19.

\eof
\name{summary.permax}
\alias{summary.permax}
\alias{print.summary.permax}
\title{
Summarizes the output of permax
}
\description{
Finds and prints the most significant genes in the output of \code{permax}
}
\usage{
summary.permax(object, data, nl=25, nr=25, ...)
}
\arguments{
\item{object}{
A dataframe of class permax (created by \code{permax})
}
\item{data}{
The data matrix used as input to permax.  If given, the rows of d
corresponding to the most significant genes will also be printed.
}
\item{nl}{
The nl most significant genes in the lower tail will be printed
}
\item{nr}{
The nr most significant genes in the upper tail will be printed
}
\item{...}{
Supplied for compatibility but not used.
}  }
\details{
If d is given, it must be a data frame with \code{row.names(d)} corresponding
to \code{row.names(object)}, or a matrix with \code{dimnames(d)[[1]]}
corresponding to \code{row.names(object)}.
The purpose of including d is primarily to print the
rows of the original data corresponding to the most significant
statistics.  
}
\seealso{
permax
}
\examples{
# An example is given in the permax help file
}
\keyword{print}
% Converted by Sd2Rd version 1.19.

\eof
